#
# spec file for package xfce4-screensaver
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with git
Name:           xfce4-screensaver
Version:        4.18.2
Release:        1.1
Summary:        Screensaver and locker for Xfce
License:        GPL-2.0-only
Group:          System/GUI/XFCE
URL:            https://docs.xfce.org/apps/xfce4-screensaver/start
Source:         https://archive.xfce.org/src/apps/xfce4-screensaver/4.18/%{name}-%{version}.tar.bz2
BuildRequires:  intltool
BuildRequires:  pam-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig
BuildRequires:  xfce4-session
BuildRequires:  xfconf >= 4.12.1
BuildRequires:  xscreensaver-data
BuildRequires:  pkgconfig(dbus-1) >= 0.30
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(garcon-1) >= 0.5.0
BuildRequires:  pkgconfig(glib-2.0) >= 2.50.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.24.0
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(libwnck-3.0) >= 3.20
BuildRequires:  pkgconfig(libxfce4ui-2) >= 4.18.4
BuildRequires:  pkgconfig(libxfce4util-1.0) >= 4.12.1
BuildRequires:  pkgconfig(libxklavier) >= 5.2
BuildRequires:  pkgconfig(x11) >= 1.0
BuildRequires:  pkgconfig(xrandr) >= 1.3
BuildRequires:  pkgconfig(xscrnsaver)
%if %{with git}
BuildRequires:  xfce4-dev-tools
%endif
Requires:       xfconf
Recommends:     %{name}-lang
Conflicts:      xscreensaver

%description
xfce4-screensaver is a screen saver and locker that integrates with the Xfce desktop.
This software is not ready for production machines yet. Please use with caution.

Add xfce4-screensaver-command -l to xflock4 script for it to work properly.

%lang_package

%prep
%autosetup -p1

%build
%if %{with git}
NOCONFIGURE=1 ./autogen.sh
%configure \
    --enable-maintainer-mode \
    --with-systemd     \
    --enable-pam       \
    --enable-locking   \
    --with-console-kit \
    --with-pam-auth-type=common
%else
%configure  \
    --with-systemd     \
    --enable-pam       \
    --enable-locking   \
    --with-console-kit \
    --with-pam-auth-type=common
%endif

%make_build

%install
%make_install
%find_lang %{name}
%if 0%{?suse_version} > 1500
mkdir -p %{buildroot}%{_pam_vendordir}
mv %{buildroot}%{_sysconfdir}/pam.d/xfce4-screensaver %{buildroot}%{_pam_vendordir}
%endif

%if 0%{?suse_version} > 1500
%pre
# Prepare for migration to /usr/lib; save any old .rpmsave
for i in pam.d/xfce4-screensaver ; do
     test -f %{_sysconfdir}/${i}.rpmsave && mv -v %{_sysconfdir}/${i}.rpmsave %{_sysconfdir}/${i}.rpmsave.old ||:
done

%posttrans
# Migration to /usr/lib, restore just created .rpmsave
for i in pam.d/xfce4-screensaver ; do
     test -f %{_sysconfdir}/${i}.rpmsave && mv -v %{_sysconfdir}/${i}.rpmsave %{_sysconfdir}/${i} ||:
done
%endif

%files -f  %{name}.lang
%license COPYING COPYING.LGPL COPYING.LIB
%if %{with git}
%doc README.md NEWS TODO
%else
%doc README.md NEWS TODO ChangeLog
%endif
%dir %{_sysconfdir}/xdg/menus
%dir %{_datadir}/applications/screensavers
%dir %{_datadir}/desktop-directories
%dir %{_datadir}/icons/hicolor
%dir %{_libexecdir}/xfce4-screensaver/
%config %{_sysconfdir}/xdg/autostart/xfce4-screensaver.desktop
%config %{_sysconfdir}/xdg/menus/xfce4-screensavers.menu
%if 0%{?suse_version} > 1500
%{_pam_vendordir}/xfce4-screensaver
%else
%config %{_sysconfdir}/pam.d/xfce4-screensaver
%endif
%{_bindir}/xfce4-screensaver
%{_bindir}/xfce4-screensaver-command
%{_bindir}/xfce4-screensaver-configure
%{_bindir}/xfce4-screensaver-preferences
%{_datadir}/applications/screensavers/xfce-floaters.desktop
%{_datadir}/applications/xfce4-screensaver-preferences.desktop
%{_datadir}/applications/screensavers/xfce-personal-slideshow.desktop
%{_datadir}/applications/screensavers/xfce-popsquares.desktop
%{_datadir}/dbus-1/services/org.xfce.ScreenSaver.service
%{_datadir}/desktop-directories/xfce4-screensaver.directory
%{_libexecdir}/xfce4-screensaver-*
%{_libexecdir}/xfce4-screensaver/*
%{_mandir}/man1/xfce4-screensaver-command.1%{?ext_man}
%{_mandir}/man1/xfce4-screensaver-preferences.1%{?ext_man}
%{_mandir}/man1/xfce4-screensaver.1%{?ext_man}
%{_datadir}/pixmaps/xfce-logo-white.svg
%{_datadir}/icons/hicolor/*

%changelog
* Tue May 30 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.18.2
  * screensaver-configure: Ensure consistent dialog positioning
  * screensaver-configure: Remove dead code
  * screensaver-configure: Improve some strings
  * screensaver-configure: Print errors on stderr without translating
  * screensaver-configure: Replace single quotes with double quotes in _()
  * screensaver-configure: Get translated strings from desktop files
  * screensaver-configure: Fix broken translations
  * screensaver-configure: Set dialogs modal
  * Revert "prefs-dialog: Grey out prefs button for popsquares (no prefs)"
  * screensaver-configure: Fix broken prefs
  * screensaver-configure: Fix critical when closing dialog
  * prefs-dialog: Grey out prefs button for popsquares (no prefs)
  * Bump GTK version and remove dead code
  * Keep "lock-on-sleep" in sync with other components via XfceScreensaver
  * *.desktop: Distinguishing our screensaver from others (Fixes #17)
  * Use GLib wrappers for memory allocation
  * Fix unix.Malloc warnings from scan-build 15.0.7
  * Fix core.uninitialized.Assign warnings from scan-build 15.0.7
  * Fix deadcode.DeadStores warnings from scan-build 15.0.7
  * Avoid duplicated code
  * manager: Do not discard monitors without model and manufacturer
  * Translation Updates
- Remove xfce4-screensaver-manager-efifb-lockup-fix.patch
* Mon May  1 2023 Takashi Iwai <tiwai@suse.com>
- Fix hang up with efifb / nomodeset (bsc#1210562):
  xfce4-screensaver-manager-efifb-lockup-fix.patch
* Mon Mar 27 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.18.1
  * Refactor spawn_make_environment_for_display()
* Sun Mar 19 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.18.0
  * Add copyright notice to configure.ac
  * Make missing GNOME Keyring PAM module warning quiet (Fixes #46)
  * build: Fix --disable-locking (Fixes #83)
  * Remove duplicated lines in README (Fixes #109)
  * savers: Fix critical warnings on exit
  * savers: Fix critical warnings from GSThemeWindow on "realize"
  * Do not redirect stderr for our own commands
  * Round the user picture on lock dialog.
  * build: Do not warn if PAM prefix is correct
  * Improve lightdm detection (Fixes #39)
  * build: Fix -Wunused-value compiler warning
  * build: Fix -Wdeclaration-after-statement compiler warning
  * build: Fix -Wsign-compare compiler warning
  * build: Use XDT_FEATURE_DEBUG
  * Fix use-after-free crash in xfce4-screensaver-dialog
  * Fix D-Bus sleep inhibit when screen locker is disabled
  * Complete previous commit
  * Fix Xfconf memory management
  * build: Set GLib macros via XDT_CHECK_PACKAGE
  * autogen.sh: Do not `mkdir m4`
  * Fix crash when XDG_PICTURES_DIR is not set (Fixes #86)
  * Fix build warning from Clang
  * --with-password-helper expects full pathname of password helper
  * Add missing zeroing of timeout_id in dialog_timed_out() timer handler
  * Fix wrong signal name for GtkSpinButton
  * Remove ENABLE_NLS ifdefs and use xfce_textdomain()
  * build: Fix intltool lock file problem during make distcheck
  * Fix compilation warnings
  * autoconf: Some updates
  * Translation Updates
- Remove _service file
* Tue Jan  3 2023 Stefan Schubert <schubi@suse.com>
- Migration of PAM settings to /usr/lib/pam.d.
* Fri Jan 15 2021 Predrag Ivanović <predivan@mts.rs>
- Unbreak Leap build.
  * Make "%%(_libexecdir}" file list more explicit, thus avoiding
    '/usr/lib/debug' being picked up on Leap, where libexec is '/usr/lib'.
* Sun Jan  3 2021 Vinzenz Vietzke <vinz@vinzv.de>
- Update to version 4.16.0
  * Changed version scheme from 0.x to 4.16.0 to align with the new
    Libxfce4util and Xfconf GIR requirements
  * xfce4-screensaver-configure: Use GIRepository of libxfce4util and
    xfconf (gxo#apps/xfce4-screensaver#11)
  * Change type of seconds to guint in add_lock_timer
  * Check dbus system_connection in add_sleep_inhibit
  * Cleanup GSourceFunc usage
  * Convert date_time_update to a timer function
  * Fix format specifiers in lock_timer
  * Fix issues connected to dbus (gxo#apps/xfce4-screensaver#66)
  * Fix pam_strerror usage
  * Pass constants to XSetScreenSaver
  * Plug memleak in get_x11_idle_info
  * Remove obsolete check for scrnsaver.h from configure.ac
  * Translation Updates
* Sun Nov  8 2020 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 0.1.11
  * Configuration Update:
    This release updates the DPMS settings used for the Blank screensaver.
    Timeouts are now stored in seconds instead of minutes, with the default
    DPMS sleep now 5 seconds after the screensaver goes active. Xfconf:
    /xfce4-screensaver/screensavers/xfce-blank/dpms-sleep-after
  * Theme Update:
    This release uses a new icon name, org.xfce.ScreenSaver, instead of the
    generic preferences-desktop-screensaver.
  * Builds: Move from exo-csource to xdt-csource (bxo#16717)
  * CI: Add basic GitLab pipeline
  * distcheck: Add missing gs-auth-pam.c
  * DPMS: Change sleep settings to seconds, default after 5 seconds
    (gxo#apps/xfce4-screensaver#27)
  * Fix: Catch gs_listener_dbus_init failures
  * Fix: remove unused flag --no-daemon
  * Icons: New icons and rDNS icon name, org.xfce.ScreenSaver
  * Internal: Change timers from milliseconds to seconds
  * README.md: Note setuid requirement after install with shadow/bsdauth
    (gxo#apps/xfce4-screensaver#9)
  * xfce4-screensaver.common-auth: replace @include with standard systax
    (gxo#apps/xfce4-screensaver#6).
  * Translation Updates
- Obsoletes patch xfce4-screensaver_pam_fix_opensuse.patch
* Thu Aug 27 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Fixes for %%_libexecdir changing to /usr/libexec (bsc#1174075)
* Sun Mar 29 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 0.1.10
  * Send DBus lock responses for xfce4-session support (bxo#16522)
  * Translation Update
* Mon Mar 23 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 0.1.9
  * Replace deprecated GTimeVal usage
  * Rebuild windows on monitor reconfiguration
  * Draw overlays during window reconstruction to protect screen
  * Do not activate DPMS when screensaver is inactive (bxo#16327)
  * Better handling of multi-monitor and lid-close events (bxo#16102)
  * Update LINGUAS (bxo#15949)
  * Fix decimal properties when running through atof
  * Return 1 on lock command failure (bxo#15945)
  * Rename 'Pictures folder' to 'Slideshow' (bxo#15589)
  * Raise NameError and TypeError (bxo#15830)
  * Fix float parsing error (bxo#16295)
  * Fix inhibitor proxying (bxo#16356)
  * Fix inhibitor listing in xfce4-screensaver-command (bxo#16355)
  * Add systemd sleep inhibitor (bxo#15929)
  * Fix dbus inhibition (bxo#16365)
  * dbus: Prevent overzealous activation (bxo#16365)
  * Translation Updates
* Thu Sep  5 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Prevent parallel installation of xscreensaver by dropping
  xscreensaver-data recommendation and make sure xscreensaver is
  removed from existing systems (boo#1149209)
* Fri Aug 16 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Fixed sources in spec file
* Mon Aug 12 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 0.1.8
  * Optional screensaver inhibition for fullscreen apps
  * Blank screensaver now supports DPMS (bxo#15216)
  * Add dependency on libwnck >= 3.20
  * Translation Updates
- Fixed up spec file
* Sun Jul 28 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 0.1.7
  * Added configuration tool for individual screensavers
  * Added support for on-screen keyboards
  * Drop libXxf86 dependency, no longer implemented or available
  * Removed unneeded login window construction code
  * Removed window shaking on failed login
  * Removed unused session-idle signal
  * Removed unused code from gs-manager/gs-window-x11
  * Simplified lock screen code
  * Simplified screensaver activation and locking code
  * Improved wallpaper drawing at 2x scale
  * Migrated xfce4-screensaver-command to GDBus
  * Fixed confusion between saver and lock timeouts
  * Translation updates
* Sun Jun 30 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 0.1.6
  * Fixed flickering in the password dialog
  * Fixed password dialog appearance, visual artifacts with
    various themes are resolved
  * Remove reference to pkg-config file (.pc) (bxo#15597)
  * Cleaned up kdb-indicator logic
  * Consolidated debug function calls
  * Moved job theme processing out of gs-manager
  * Removed drag-and-drop theme installation
  * Removed placeholder widgets from the glade template
  * Removed unused callbacks
  * Simplified handling of user preferences
  * Translation Updates
- Removed devel package as pkg-config file was removed
* Mon Jun 17 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Replace BuildRequires systemd-devel with pkgconfig(libsystemd)
* Thu Jun 13 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 0.1.5
  * Added support for elogind (bxo#15243)
  * Added support for profile images from AccountsService (bxo#15235)
  * Removed a lot of unused code (2,700+ lines)
  * Simplified monitor-handling logic
  * More consistent spacing in makefiles
  * Added categories to display in the Settings Manager (bxo#15507)
  * Added a fallback idle timer for when X11 screensaver doesn't notify
  * Fixed warning during configure stage (bxo#15552)
  * Fixed Inhibitor lock (bxo#15551)
  * Hide screensaver themes from 'Open with' options (bxo#15531)
  * Made numerous cppcheck, cpplint, and Coverity Scan fixes
  * Constant variables guarding dead code
  * Dereferencing before/after null
  * Unchecked return values
  * Unused variables
  * Memory leaks
  * Translation Updates
* Wed Jun  5 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Added bcond to build with sources from git master branch
- Added --with-console-kit needed for PrepareForSleep signal
- Added OBS service file to fetch git master sources when needed
* Fri Mar 22 2019 Vinzenz Vietzke <vinz@vinzv.de>
- update to 0.1.4
  * Features:
  - Added support for locking on suspend (bxo#15001)
  * Bug Fixes:
  - Fix password entry after stealing focus (bxo#15042)
  * General:
  - Faster screen locking when activated
  - Faster renderering of the authentication prompt
  - Improved support for monitor dis-/connection events
  - Improved lock screen display on lid open events
  - Improved idle activation
  - Improved low-power state, screensavers are now suspended
    when monitors are powered off via DPMS (deb#921835)
  * Translation Updates:
    Basque, Belarusian, Catalan, Czech, Danish, Galician, Lithuanian,
    Malay, Portuguese, Russian, Serbian, Spanish, Swedish
* Sat Nov 24 2018 Maurizio Galli <maurizio.galli@gmail.com>
- update to 0.1.3
  * Features:
  - All available settings are now availble in the Preferences dialog
  - Locking on user inactivity is now based on X11 Screensaver signals
  - Xfce Screensaver now respects the xdg-screensaver state
  - Screensaver and lock screen functionality can now be toggled separately
  * General:
  - Removed deprecated DBUS methods and signals from documentation
  * Preferences:
  - Dropped unused preferences
  - Renamed all Xfconf properties for improved clarity
  - Embedded keyboard options have been disabled since they are currently
    non-functional
  * Bug Fixes:
  - Replaced Help link with a link to the Xfce Documentation (Xfce #14877)
  - Added /usr/lib and /usr/libexec as trusted engine paths, enables
    local installs with access to existing screensavers (Xfce #14883)
  - Fixed screen blanking and locking on BSD (Xfce #14846)
  - Fixed lock screen crash on laptop lid-close events (GTK #1466)
  - Fixed daemon crash when scrolling through available themes
  - Fixed minimum window size to allow resizing much smaller
  - Renamed screensavers to prevent conflicts with MATE Screensaver
  - Reduced flicker rate when multiple keyboard layouts are available
  * Build Improvements
  - Silence warning: "ar: 'u' modifier ignored since 'D' is the default"
  - Fix warning: "Target given more than once in the same rule"
  * Code Quality:
  - Applied cpplint fixes and added cpplint configuration file
  - Cleaned up unused variables, trailing spaces, and deprecated code
  - Glade templates were cleaned up and organized for easier maintenance
  * Translation Updates
  - added %%autosetup macro to spec file
  - removed autogen.sh from spec file
* Tue Nov  6 2018 Maurizio Galli <maurizio.galli@gmail.com>
- Added tips to description
* Tue Nov  6 2018 Maurizio Galli <maurizio.galli@gmail.com>
- Update to 0.1.2
  * Resolve hidden libxfce4ui 4.13 requirement (bxo#14821)
  * Avoid hard-coded paths for systems that do not use /usr (bxo #14822)
- 0.1.1
  * Support color settings for Xfdesktop 4.12
  * Fallback to the Xfdesktop default color background (dark blue)
  * UI files are now compiled and included in the binaries
  * Root warning is now an InfoBar to make it more visible
  * Enabled embedding in the Xfce Settings Manager
  * Fix crash with no background placement, fix color settings (bxo#14769)
  * Redraw the screensaver on monitor configuration events (bxo#14796)
  * Automate detection of PAM configuration, add flag to override  (bxo#14779)
  * Notify invalid lid-switch configuration and add Resolve button (bxo#14782)
  * Fix appearance with the Adwaita GTK theme
  * Fix builds on OpenBSD, build status can now be tracked on the Xfce Build Bot
- Updated patch for openSUSE PAM support
- Cleaned and fixed spec file to new version files and flags
* Wed Oct 17 2018 Maurizio Galli <maurizio.galli@gmail.com>
- Created and added patch for PAM support
- Added systemd support in build
* Wed Oct 17 2018 Maurizio Galli <maurizio.galli@gmail.com>
- Edit of %%configure
* Wed Oct 17 2018 Maurizio Galli <maurizio.galli@gmail.com>
- Added  --prefix=/usr --sysconfdir=/etc flags to build
* Mon Oct 15 2018 Maurizio Galli <maurizio.galli@gmail.com>
- Initial Build 0.1.0
